@@ -1,3 +1,3 @@
 #!/bin/sh
 python setup.py sdist bdist_wheel
-twine upload --sign dist/*
+twine upload dist/*
